@@ -36,6 +36,14 @@
         <source>Authorization expired, please re-login</source>
         <translation>Autorització expirada, si us plau torni a iniciar sessió</translation>
     </message>
+    <message>
+        <source>Failed to remove local repos sync token: %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to get repo sync information from server: %1</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>AccountSettingsDialog</name>
@@ -135,14 +143,6 @@
         <source>not logged in</source>
         <translation>no està autenticat</translation>
     </message>
-    <message>
-        <source>Failed to remove local repos sync token: %1</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Failed to get repo sync information from server: %1</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Form</source>
         <translation type="unfinished"/>
@@ -847,6 +847,10 @@ failed to upload.</source>
         <source>Unable to open cache folder</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Search files</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileBrowserProgressDialog</name>
@@ -894,6 +898,44 @@ failed to upload.</source>
         <source>Abort</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Saving</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>File save failed</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>FileBrowserSearchModel</name>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Last Modified</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Kind</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>FileBrowserSearchView</name>
+    <message>
+        <source>&amp;Show in folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Show in folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileNetworkTask</name>
@@ -1265,10 +1307,6 @@ Do you like to download your default library?</source>
         <source>Failed to save current account</source>
         <translation>No s&apos;ha pogut guardar el compte actual</translation>
     </message>
-    <message>
-        <source>Two Factor Authentication</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>%1 Server Address</source>
         <translation type="unfinished"/>
@@ -1285,10 +1323,6 @@ Do you like to download your default library?</source>
         <source>Please enter the password</source>
         <translation>Introduïu la contrasenya</translation>
     </message>
-    <message>
-        <source>Enter the two factor authentication token</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Incorrect email or password</source>
         <translation>El correu electrònic o la contrasenya són incorrectes</translation>
@@ -1357,6 +1391,10 @@ Do you like to download your default library?</source>
         <source>Cancel</source>
         <translation>Cancel·la</translation>
     </message>
+    <message>
+        <source>Automatic Login</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>LogoutView</name>
@@ -1414,11 +1452,6 @@ File is locked by other application. This file will be updated when you close th
 Some file in this folder is locked by other application. This folder will be updated when you close the application.</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Failed to sync file %1
-File is locked by other user on the server. Update to this file is not uploaded.</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Failed to sync %1
 File path is ended with space or period and cannot be created on Windows.</source>
@@ -1446,6 +1479,15 @@ The library owner&apos;s storage space is used up.</source>
         <translation>No s&apos;ha sincronitzat &quot;%1&quot;.
 Perquè s&apos;ha superat el límit de capacitat al compte del propietari.</translation>
     </message>
+    <message>
+        <source>Update to file %1 is denied by folder permission setting.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to sync file %1
+File is locked by another user. Update to this file is not uploaded.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrivateShareDialog</name>
@@ -2064,6 +2106,10 @@ Perquè s&apos;ha superat el límit de capacitat al compte del propietari.</tran
         <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Update to file denied by folder permission setting</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ReliablePostFileTask</name>
@@ -2991,6 +3037,41 @@ Perquè s&apos;ha superat el límit de capacitat al compte del propietari.</tran
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>TwoFactorDialog</name>
+    <message>
+        <source>Enter the two factor authentication token</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Two Factor Authentication</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Please enter the two factor authentication token</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Dialog</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>mText</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Remember this device</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>UninstallHelperDialog</name>
     <message>
