@@ -36,6 +36,14 @@
         <source>Authorization expired, please re-login</source>
         <translation>承認タイムアウト、再ログインしてください</translation>
     </message>
+    <message>
+        <source>Failed to remove local repos sync token: %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to get repo sync information from server: %1</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>AccountSettingsDialog</name>
@@ -134,14 +142,6 @@
         <source>not logged in</source>
         <translation>ログインはまだ</translation>
     </message>
-    <message>
-        <source>Failed to remove local repos sync token: %1</source>
-        <translation>%1ローカルりポジトリの同期トークン削除に失敗しました</translation>
-    </message>
-    <message>
-        <source>Failed to get repo sync information from server: %1</source>
-        <translation>リポジトリ同期情報の取得に失敗しました</translation>
-    </message>
     <message>
         <source>Form</source>
         <translation>フォーム</translation>
@@ -848,6 +848,10 @@ failed to upload.</source>
         <source>Unable to open cache folder</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Search files</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileBrowserProgressDialog</name>
@@ -895,6 +899,44 @@ failed to upload.</source>
         <source>Abort</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Saving</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>File save failed</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>FileBrowserSearchModel</name>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Last Modified</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Kind</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>FileBrowserSearchView</name>
+    <message>
+        <source>&amp;Show in folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Show in folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileNetworkTask</name>
@@ -1263,10 +1305,6 @@ Do you like to download your default library?</source>
         <source>Failed to save current account</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Two Factor Authentication</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>%1 Server Address</source>
         <translation type="unfinished"/>
@@ -1283,10 +1321,6 @@ Do you like to download your default library?</source>
         <source>Please enter the password</source>
         <translation>パスワードを入力してください</translation>
     </message>
-    <message>
-        <source>Enter the two factor authentication token</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Incorrect email or password</source>
         <translation>メールアドレスまたはパスワードが正しくありません</translation>
@@ -1355,6 +1389,10 @@ Do you like to download your default library?</source>
         <source>Cancel</source>
         <translation>キャンセル</translation>
     </message>
+    <message>
+        <source>Automatic Login</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>LogoutView</name>
@@ -1411,11 +1449,6 @@ File is locked by other application. This file will be updated when you close th
 Some file in this folder is locked by other application. This folder will be updated when you close the application.</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Failed to sync file %1
-File is locked by other user on the server. Update to this file is not uploaded.</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Failed to sync %1
 File path is ended with space or period and cannot be created on Windows.</source>
@@ -1441,6 +1474,15 @@ Access denied to service</source>
 The library owner&apos;s storage space is used up.</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Update to file %1 is denied by folder permission setting.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to sync file %1
+File is locked by another user. Update to this file is not uploaded.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrivateShareDialog</name>
@@ -2059,6 +2101,10 @@ The library owner&apos;s storage space is used up.</source>
         <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Update to file denied by folder permission setting</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ReliablePostFileTask</name>
@@ -2986,6 +3032,41 @@ The library owner&apos;s storage space is used up.</source>
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>TwoFactorDialog</name>
+    <message>
+        <source>Enter the two factor authentication token</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Two Factor Authentication</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Please enter the two factor authentication token</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Dialog</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>mText</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Remember this device</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>UninstallHelperDialog</name>
     <message>
