@@ -36,6 +36,14 @@
         <source>Authorization expired, please re-login</source>
         <translation>Innlogging utløpt, logg inn på nytt</translation>
     </message>
+    <message>
+        <source>Failed to remove local repos sync token: %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to get repo sync information from server: %1</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>AccountSettingsDialog</name>
@@ -134,14 +142,6 @@
         <source>not logged in</source>
         <translation>ikke logget inn</translation>
     </message>
-    <message>
-        <source>Failed to remove local repos sync token: %1</source>
-        <translation>Mislykkes med å fjerne den lokale synkroniserings-token. %1</translation>
-    </message>
-    <message>
-        <source>Failed to get repo sync information from server: %1</source>
-        <translation>Mislyktes i få &quot;repo sync&quot; informasjon fra server. %1</translation>
-    </message>
     <message>
         <source>Form</source>
         <translation>Formulær</translation>
@@ -850,6 +850,10 @@ opplasting mislyktes</translation>
         <source>Unable to open cache folder</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Search files</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileBrowserProgressDialog</name>
@@ -897,6 +901,44 @@ opplasting mislyktes</translation>
         <source>Abort</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Saving</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>File save failed</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>FileBrowserSearchModel</name>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Last Modified</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Kind</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>FileBrowserSearchView</name>
+    <message>
+        <source>&amp;Show in folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Show in folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileNetworkTask</name>
@@ -1272,10 +1314,6 @@ Do you like to download your default library?</source>
         <source>Failed to save current account</source>
         <translation>Kunne ikke lagre nåværende konto</translation>
     </message>
-    <message>
-        <source>Two Factor Authentication</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>%1 Server Address</source>
         <translation type="unfinished"/>
@@ -1292,10 +1330,6 @@ Do you like to download your default library?</source>
         <source>Please enter the password</source>
         <translation>Skriv inn passordet</translation>
     </message>
-    <message>
-        <source>Enter the two factor authentication token</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Incorrect email or password</source>
         <translation>Feil e-postadresse eller passord</translation>
@@ -1364,6 +1398,10 @@ Do you like to download your default library?</source>
         <source>Cancel</source>
         <translation>Avbryt</translation>
     </message>
+    <message>
+        <source>Automatic Login</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>LogoutView</name>
@@ -1421,11 +1459,6 @@ File is locked by other application. This file will be updated when you close th
 Some file in this folder is locked by other application. This folder will be updated when you close the application.</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Failed to sync file %1
-File is locked by other user on the server. Update to this file is not uploaded.</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Failed to sync %1
 File path is ended with space or period and cannot be created on Windows.</source>
@@ -1453,6 +1486,15 @@ The library owner&apos;s storage space is used up.</source>
         <translation>&quot;%1&quot; ble ikke synkronisert.
 Bibliotekets eier har gått tom for lagringsplass.</translation>
     </message>
+    <message>
+        <source>Update to file %1 is denied by folder permission setting.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to sync file %1
+File is locked by another user. Update to this file is not uploaded.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrivateShareDialog</name>
@@ -2071,6 +2113,10 @@ Bibliotekets eier har gått tom for lagringsplass.</translation>
         <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Update to file denied by folder permission setting</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ReliablePostFileTask</name>
@@ -2998,6 +3044,41 @@ Bibliotekets eier har gått tom for lagringsplass.</translation>
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>TwoFactorDialog</name>
+    <message>
+        <source>Enter the two factor authentication token</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Two Factor Authentication</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Please enter the two factor authentication token</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Dialog</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>mText</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Remember this device</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>UninstallHelperDialog</name>
     <message>
