@@ -344,4 +344,24 @@ private:
     const QString file_name_;
 };
 
+struct ServerIndexProgress {
+    qint64 total;
+    qint64 indexed;
+    qint64 status;
+};
+
+class GetIndexProgressRequest : public SeafileApiRequest {
+    Q_OBJECT
+public:
+    GetIndexProgressRequest(const QUrl &url, const QString &task_id);
+signals:
+    void success(const ServerIndexProgress& result);
+
+protected slots:
+    void requestSuccess(QNetworkReply& reply);
+
+private:
+    Q_DISABLE_COPY(GetIndexProgressRequest);
+};
+
 #endif  // SEAFILE_CLIENT_FILE_BROWSER_REQUESTS_H
